/*
 * OpenDEM www.opendem.info
 * the code is under the unlicense license, do what you like
 */

package info.opendem.opendemtracker;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

import info.opendem.opendemtracker.R;
import android.app.Dialog;
import android.content.Context;
import android.content.Intent;
import android.net.MailTo;
import android.net.Uri;
import android.os.Bundle;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;

public class HelpDialog extends Dialog {

	private static Context mContext = null;

	public HelpDialog(Context context) {
		super(context);
		mContext = context;
	}

	@Override
	public void onCreate(Bundle savedInstanceState) {
		setContentView(R.layout.help);
		WebView help = (WebView)findViewById(R.id.helpView);
		help.setWebViewClient(new WebViewClient(){
			@Override
			public boolean shouldOverrideUrlLoading(WebView view, String url) {

				if(url.startsWith("mailto:")){
		                Intent i = new Intent(Intent.ACTION_SENDTO, Uri.parse(url));
		            	i.putExtra(Intent.EXTRA_SUBJECT, "Feedback OpenDemTracker");		
		                mContext.startActivity(i);   
		            }
		            else{
		                view.loadUrl(url);  
		            }
		            return true;
			
				
			}
		});
		
		String helpText = "<h1>Help</h1>";
		helpText += "<p><strong><i>GPS tracking and height recording based on the barometric sensor of your mobile device.</i></strong><br />";
		helpText += "<p><strong>For this app, a GPS receiver and a barometric sensor are required.</strong><br />";
		helpText += "<strong>An internet connection is required when:</strong></p>";
		helpText += "<ol><li><strong>the recorded data should be published under the Open Database License (ODbL) on the OpenDEM server.</strong></li>";
		helpText += "<li><strong>weather stations should be used as reference for correction of the data*.</strong></li>";
		helpText += "<li><strong>a SRTM elevation service should be used for the computation of the initial height value.</strong></li></ol>";
		helpText += "<p>*Only available for Germany and the surrounding area. For more information, see <a href=\"http://www.opendem.info/android_barometer.html\">here</a>. </p>";
		helpText += "<p>Nevertheless, you could use the data of this app for post processing at any place on Earth. The recorded data could be saved directly on your mobile device.</p>";
		helpText += "<p> <strong>Be aware that this is an app with experimental status. With the present reference data of the weather APIs, it is not possible to create a reliable correction of the data over longer time periods. See <a href=\"http://www.opendem.info/android_barometer.html\">here</a> for further information.</strong></p>";
		helpText += "<p>There are also other conditions which could lead to improper results:<br/>";
		helpText += "- relief, e.g. at the windward and leeward side of mountains<br/>";
		helpText += "- atmospheric instability, e.g. thermal bubbles<br/>";
		helpText += "- deviations from the standard atmosphre, e.g. important for the calculation of the barometric scale factor</p>";
		helpText += "<p><strong>Nonetheless, the first 10 minutes of every recorded track could be a starting point to build up an OpenDEM.</strong></p>";
		helpText += "<h3>Lets see how it works.</h3>";
		helpText += "<p>Have a look at the main view on your mobile device in tabularised form:</p>";
		helpText += "<table width=\"200\" border=\"1\"><tr><td colspan=\"4\" style=\"background-color:#000000; color: #FFFFFF;\"><span>initial latitude</span></td></tr>";
		helpText += "<tr><td colspan=\"5\" style=\"background-color:#000000; color: #FFFFFF;\"><span>initial longitude</span></td></tr>";
		helpText += "<tr><td colspan=\"5\" style=\"background-color:#000000; color: #FFFFFF;\"><span>height input type</span></td></tr>";
		helpText += "<tr><td colspan=\"5\" style=\"background-color:#000000; color: #FFFFFF;\"><span>insert actual height </span><span style=\"color: #FF0000;\">[___]</span></td></tr>";
		helpText += "<tr><td style=\"background-color:#555555; color: #FFFFFF;\"><span>start</span></td>";
		helpText += "<td style=\"background-color:#555555; color: #FFFFFF;\"><span>save</span></td>";
		helpText += "<td style=\"background-color:#555555; color: #FFFFFF;\"><span>map</span></td>";
		helpText += "<td style=\"background-color:#555555;color: #FFFFFF;\"><span>exit</span></td>";
		helpText += "<td style=\"background-color:#555555;color: #FFFFFF;\"><span>help</span></td></tr>";
		helpText += "<tr><td colspan=\"5\" style=\"background-color:#AAAAAA; color: #FFFFFF;\"><span>status</span></td></tr></table>";
		helpText += "<p>First, insert your actual height at the starting point into the edit textbox &quot;insert actual height&quot;. If you do not know the actual height at your position you could also press the &quot;start&quot; button and use a web service for height calculation. The service is provided by <a href=\"https://mapzen.com\">mapzen</a> on the basis of SRTM data. SRTM measures the Earths surface (including buildings and trees) and has an RMS error of +- 7 m. If an Internet connection is not available or the web service is not able to calculate a height value, the GPS height is taken as the height input.</p>";
		helpText += "<p>Press &quot;start&quot; after you edit  the actual height from whatever source.</p>";
		helpText += "<p>It takes some time for the mobile device to fix the actual GPS coordinates. You get the following message in the status field: &quot;Please wait while fixing the initial GPS position!&quot;. Please do not change your position until the coordinates are fixed. Otherwise, your inserted height will not fit to the fixed coordinates. After fixing, you get a message in the status field &quot;Logging data&quot;. The accuracy of the GPS position could be poor (GPS  accuracy is also logged). If there is temporarily no GPS signal, the app will not log and wait for the next signal. </p>";
		helpText += "<p>The aim of the project is to generate a Digital Terrain Model (DTM). Please do not record tracks along  man-made objects like bridges, houses, or elevated railways. Dykes and  railroad embankments are usually part of a DTM.</p>";
		helpText += "<p>The actual pressure of the German weather service (<a href=\"http://www.dwd.de\">Deutscher Wetterdienst</a>) will be requested for the actual pressure at the next weather station. Every 10 minutes the service will be requested. Unfortunately, the update interval is about half an hour and sometimes there are errors or non-values for the actual pressure. This is  corrected in the historical datasets, which could be  used for post-processing. Nevertheless, pressure could change at small scales, and there is no guarantee that the corrected heights are  better. Be aware that the DWD data are copyrighted (see <a href=\"ftp://ftp-cdc.dwd.de/pub/CDC/Terms_of_use.pdf\">here</a>).</p>";
		helpText += "<p>Another mobile or GPS with barometric sensor could be used as a reference for self-made corrections. ";
		helpText += "Use the available manual correction <a href=\"http://www.opendem.info/android_manual_correction_tool.html\">online tool</a> on the OpenDEM website to correct your data now!</p>";
		helpText += "<p><strong>Save your data</strong></p>";
		helpText += "<p>By pressing the &quot;save&quot; button, a dialog opens where you could enter a name under which the data will be saved.</p>";
		helpText += "<table width=\"200\" border=\"1\"><tr><td style=\"background-color:#000000;color: #FFFFFF;\"><span><span style=\"background-color:#000000; color: #FF0000;\">[</span>filename<span style=\"background-color:#000000; color: #FF0000;\">]</span></span></td></tr><tr>";
		helpText += " <td style=\"background-color:#000000;color: #FFFFFF;\"><span>Save only on device</span></td></tr>";
		helpText += "<tr><td style=\"background-color:#000000;color: #FFFFFF;\"><span>Save on server</span></td></tr>";
		helpText += "<tr><td style=\"background-color:#000000;color: #FFFFFF;\"><span>Save on Device and Server</span></td></tr>";
		helpText += "<tr><td style=\"background-color:#AAAAAA;color: #FFFFFF;\"><span>I agree that the stored data on the server will be published under the Open Database Licence (ODbL).<br/>No personal data are stored!<br/>Uploading and processing on device could take several minutes!</p></span></td></tr></table>";
		helpText += "<p>Edit the filename in the edit textbox &quot;filename&quot; if you want to store the data on your mobile under a unique filename. If your mobile is offline, only  saving on the device is available.</p>";
		helpText += "<p>When saving the data on the OpenDEM Server, you agree that the data is stored under the Open Database License (<a href=\"http://opendatacommons.org/licenses/odbl\">ODbL)</a>. No personal data like your call number or IP are stored.</p>";
		helpText += "<p>Please be aware that it takes some processing time when the data are saved on the device. The upload on the server could also take some time depending on the amount of data and the digit rate.</p>";
		helpText += "<h3>Map Button</h3>";
		helpText += "<p>An OpenLayers map client will open in your favorite Browser. After you accept to locate your location, the map will be centered with Web Mercator zoom level 15. If not, the location the map will be centered at lat/lon 0/0. The tracks and overviews will be draped on  the OSM map tiles.</p>";
		helpText += "<p>There is also a <a href=\"http://www.opendem.info/opendemtracker_map.html\">mapclient</a> on the server with additional functions (styling on demand, single track view, etc.).";
		helpText += "<h3>Exit Button</h3>";
		helpText += "<p>Exit the app. The app is still available in the tracklist, but will not allocate any resources.</p>";
		helpText += "<h3>Help Button</h3>";
		helpText += "<p>Get some information about the app and give some feedback.</p>";
		helpText += "<p>Additional information about the processing, stored data und project is available on the <a href=\"http://www.opendem.info\">OpenDEM</a> website.</p>";
		helpText += "<a name=\"feedback\" id=\"feedback\"><h3>Feedback</h3>Any comments, feedback, suggestions on OpenDemTracker please write to us using the link below.<br><a href=\"mailto:contact@opendemdata.info\">contact@opendemdata.info</a></a>";
		
		help.loadData(helpText, "text/html; charset=utf-8", "utf-8");
	}


}
